@@ -10,15 +10,14 @@ import time
 from dotenv import load_dotenv
 import os
 
-from ..entities.thing import Thing
+from dcd.entities.thing import Thing
 
 # The thing ID and access token
 load_dotenv()
 THING_ID = os.environ['THING_ID']
-THING_TOKEN = os.environ['THING_TOKEN']
 
 # Instantiate a thing with its credential
-my_thing = Thing(thing_id=THING_ID, token=THING_TOKEN)
+my_thing = Thing(thing_id=THING_ID)
 
 my_thing.read()
 
